#ifndef ACCESS_SETTINGS_H
#define ACCESS_SETTINGS_H

/*!
  \file
  \brief ݒ̊Ǘ

  \author Satofumi KAMIMURA

  $Id$
*/

#include <memory>
#include <vector>
#include <string>


/*!
  \brief ݒt@C̊ǗNX
*/
class AccessSettings {
  AccessSettings(void);
  AccessSettings(const AccessSettings& rhs);
  AccessSettings& operator = (const AccessSettings& rhs);

  struct pImpl;
  const std::auto_ptr<pImpl> pimpl;

public:
  std::vector<std::string> user_names_; //!< [U
  std::vector<std::string> user_password_; //!< pX[h

  std::vector<int> convert_mode_; //!< ̓[h
  std::vector<size_t> practice_num_;         //!< K

  std::vector<int> music_volume_; //!< Ȃ̃{[
  std::vector<int> effect_volume_; //!< ʉ̃{[

  size_t user_index_;           //!< I𒆂̃[UCfbNX

  std::string effect_decide_;   //!< 艹
  std::string effect_type_;     //!< ^Cv
  std::string effect_miss_;     //!< ~X^Cv

  AccessSettings(const char* savedir);
  ~AccessSettings(void);

  /*!
    \brief ēǂݍ
  */
  void reload(void);

  /*!
    \brief ۑ
  */
  void save(void);

  void deleteUser(int user_index);
};

#endif /* !ACCESS_SETTINGS_H */
